# About

The development of [badgers](https://github.com/Fraunhofer-IESE/badgers) was initially driven by Julien Siebert at the Data Science Department of the Fraunhofer Institute for Experimental Software Engineering ([IESE](https://www.iese.fraunhofer.de/)) in Kaiserslautern, Germany.

The original idea came during internal discussions with Patricia Kelbert, Adam Trendowicz, and Michael Kläs.

A big thanks to Daniel Seifert for taking the time to investigate and automate all the many things that make our lives as package contributors easier.

## Citing Badgers
    
Work In Progess

## Contributing to Badgers

Every contribution is welcome, please have a look at [CONTRIBUTING.md](https://github.com/Fraunhofer-IESE/badgers/blob/main/CONTRIBUTING.md) for more info.




